==> open-cluster-management-cluster-model-6.7.0-sources.jar: io/fabric8/openclustermanagement/api/model/cluster/v1beta1/ManagedClusterSetSpecBuilder.java <==
package io.fabric8.openclustermanagement.api.model.cluster.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ManagedClusterSetSpecBuilder extends ManagedClusterSetSpecFluentImpl<ManagedClusterSetSpecBuilder> implements VisitableBuilder<ManagedClusterSetSpec,ManagedClusterSetSpecBuilder>{
  public ManagedClusterSetSpecBuilder() {
    this(false);
  }
  public ManagedClusterSetSpecBuilder(Boolean validationEnabled) {
    this(new ManagedClusterSetSpec(), validationEnabled);
  }
  public ManagedClusterSetSpecBuilder(ManagedClusterSetSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public ManagedClusterSetSpecBuilder(ManagedClusterSetSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ManagedClusterSetSpec(), validationEnabled);
  }
  public ManagedClusterSetSpecBuilder(ManagedClusterSetSpecFluent<?> fluent,ManagedClusterSetSpec instance) {
    this(fluent, instance, false);
  }
  public ManagedClusterSetSpecBuilder(ManagedClusterSetSpecFluent<?> fluent,ManagedClusterSetSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
    }
    this.validationEnabled = validationEnabled; 
  }
  public ManagedClusterSetSpecBuilder(ManagedClusterSetSpec instance) {
    this(instance,false);
  }
  public ManagedClusterSetSpecBuilder(ManagedClusterSetSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
    }
    this.validationEnabled = validationEnabled; 
  }
  ManagedClusterSetSpecFluent<?> fluent;
  Boolean validationEnabled;
  public ManagedClusterSetSpec build() {
    ManagedClusterSetSpec buildable = new ManagedClusterSetSpec();
    return buildable;
  }
  
}

==> open-cluster-management-cluster-model-6.8.1-sources.jar: io/fabric8/openclustermanagement/api/model/cluster/v1beta1/ManagedClusterSetSpecBuilder.java <==
package io.fabric8.openclustermanagement.api.model.cluster.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ManagedClusterSetSpecBuilder extends ManagedClusterSetSpecFluent<ManagedClusterSetSpecBuilder> implements VisitableBuilder<ManagedClusterSetSpec,ManagedClusterSetSpecBuilder>{
  public ManagedClusterSetSpecBuilder() {
    this(false);
  }
  public ManagedClusterSetSpecBuilder(Boolean validationEnabled) {
    this(new ManagedClusterSetSpec(), validationEnabled);
  }
  public ManagedClusterSetSpecBuilder(ManagedClusterSetSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public ManagedClusterSetSpecBuilder(ManagedClusterSetSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ManagedClusterSetSpec(), validationEnabled);
  }
  public ManagedClusterSetSpecBuilder(ManagedClusterSetSpecFluent<?> fluent,ManagedClusterSetSpec instance) {
    this(fluent, instance, false);
  }
  public ManagedClusterSetSpecBuilder(ManagedClusterSetSpecFluent<?> fluent,ManagedClusterSetSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new ManagedClusterSetSpec());

    if (instance != null) {
    }
    this.validationEnabled = validationEnabled; 
  }
  public ManagedClusterSetSpecBuilder(ManagedClusterSetSpec instance) {
    this(instance,false);
  }
  public ManagedClusterSetSpecBuilder(ManagedClusterSetSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new ManagedClusterSetSpec());

    if (instance != null) {
    }
    this.validationEnabled = validationEnabled; 
  }
  ManagedClusterSetSpecFluent<?> fluent;
  Boolean validationEnabled;
  public ManagedClusterSetSpec build() {
    ManagedClusterSetSpec buildable = new ManagedClusterSetSpec();
    return buildable;
  }
  
}
